Flash

Struct Flash 

pub struct Flash<const PAGE_SIZE: usize, const PAGE_NUM: usize, const MINI_WRITE_SIZE: usize = 4, const MINI_READ_SIZE: usize = 1, MODE = Blocking> { /* private fields */ }
Internal flash memory driver.

Implementations

Source

impl<const PAGE_SIZE: usize, const PAGE_NUM: usize, const MINI_WRITE_SIZE: usize, const MINI_READ_SIZE: usize> Flash<PAGE_SIZE, PAGE_NUM, MINI_WRITE_SIZE, MINI_READ_SIZE, Blocking>

pub fn new_blocking() -> Self

Create a new flash driver, usable in blocking mode.

Source

impl<const PAGE_SIZE: usize, const PAGE_NUM: usize, const MINI_WRITE_SIZE: usize, const MINI_READ_SIZE: usize, MODE> Flash<PAGE_SIZE, PAGE_NUM, MINI_WRITE_SIZE, MINI_READ_SIZE, MODE>

pub fn blocking_read( &mut self, offset: u32, bytes: &mut [u8], ) -> Result<(), Error>

Blocking read.

NOTE: offset is an offset from the flash start, NOT an absolute address. For example, to read address 0x0800_1234 you have to use offset 0x1234.

pub fn blocking_write(&mut self, offset: u32, bytes: &[u8]) -> Result<(), Error>

Blocking write.

NOTE: offset is an offset from the flash start, NOT an absolute address. For example, to write address 0x0800_1234 you have to use offset 0x1234.

pub fn blocking_erase(&mut self, from: u32, to: u32) -> Result<(), Error>

Blocking erase.

NOTE: from and to are offsets from the flash start, NOT an absolute address. For example, to erase address 0x0801_0000 you have to use offset 0x1_0000.